@@ -1,9 +1,9 @@
 #' @title Shifted Binomial probabilities of ordinal responses
 #' @description Compute the shifted Binomial probabilities of ordinal responses.
 #' @aliases bitcsi
-#' @usage bitcsi(m, ordinal, csi)
+#' @usage bitcsi(m,ordinal,csi)
 #' @param m Number of ordinal categories
-#' @param ordinal Vector of ordinal responses
+#' @param ordinal Vector of ordinal responses (factor type)
 #' @param csi  Feeling parameter of the shifted Binomial distribution
 #' @export bitcsi
 #' @return A vector of the same length as ordinal, where each entry is the shifted Binomial probability 
@@ -14,13 +14,19 @@
 #' @keywords distribution
 #' @examples 
 #' data(univer)
+#' attach(univer)
 #' m<-7
-#' ordinal<-univer[,8]
 #' csi<-0.7
-#' pr<-bitcsi(m,ordinal,csi)
+#' pr<-bitcsi(m,informat,csi)
 
 
 bitcsi <-function(m,ordinal,csi){
+  
+  if (!is.factor(ordinal)){
+    stop("Response must be an ordered factor")
+  }
+  ordinal<-unclass(ordinal)
+  
   base<-log(1-csi)-log(csi)
   const<-exp(m*log(csi)-log(1-csi))
   const*kkk(m,ordinal)*exp(base*ordinal)
