@@ -2,7 +2,7 @@
 #' @description Estimate and validate a CUBE model for ordinal data, with covariates only for explaining the
 #' feeling component.
 #' @aliases cubecsi
-#' @usage cubecsi(m, ordinal, W, starting, maxiter, toler, summary)
+#' @usage cubecsi(m, ordinal, W, starting, maxiter, toler)
 #' @param m Number of ordinal categories
 #' @param ordinal Vector of ordinal responses
 #' @param W Matrix of selected covariates for explaining the feeling component
@@ -10,10 +10,9 @@
 #'  NCOL(W) + 3 to account for an intercept term for the feeling component (first entry)
 #' @param maxiter Maximum number of iterations allowed for running the optimization algorithm 
 #' @param toler Fixed error tolerance for final estimates 
-#' @param summary Logical: if TRUE, summary results of the fitting procedure are displayed on screen
 #' @return An object of the class "CUBE". For cubecsi, $niter will return a NULL value since the optimization procedure
 #'  is not iterative but based on "optim" (method = "L-BFGS-B", option hessian=TRUE). \cr $varmat will return the inverse 
-#'  of the numerically computed hessian when it is positive definite, otherwise the procedure will return a matrix of NA
+#'  of the numerically computed Hessian when it is positive definite, otherwise the procedure will return a matrix of NA
 #'   entries.
 #' @import stats
 #' @seealso \code{\link{loglikcubecsi}},  \code{\link{inibestcubecsi}},  \code{\link{CUBE}} 
@@ -30,7 +29,7 @@
 #' ordinal=nona[,1]
 #' W=nona[,2]
 #' starting=rep(0.1,4)     
-#' fit=cubecsi(m, ordinal, W, starting, maxiter=100, toler=1e-3,summary=F)
+#' fit=cubecsi(m, ordinal, W, starting, maxiter=100, toler=1e-3)
 #' param=fit$estimates
 #' pai=param[1]                        ## ML estimates for the uncertainty parameter
 #' gama=param[2:(length(param)-1)]     ## ML estimates for the coefficients of the feeling covariates
@@ -40,12 +39,12 @@
 #' BIC=fit$BIC
 #' ##########################################################
 #' data(univer)
-#' m=7 
+#' m<-7 
 #' ordinal=univer[,8]
 #' gender=univer[,4]
 #' initial=inibestcube(m,ordinal)
 #' starting=inibestcubecsi(m,ordinal,W=gender,initial,maxiter=500,toler=1e-6)
-#' fitcsi=cubecsi(m, ordinal, W=gender, starting, maxiter=100, toler=1e-3,summary=T)
+#' fitcsi=cubecsi(m, ordinal, W=gender, starting, maxiter=100, toler=1e-3)
 #' param=fitcsi$estimates
 #' pai=param[1]                       ## ML estimates for the uncertainty parameter
 #' gama=param[2:(length(param)-1)]    ## ML estimates for the coefficients of the feeling covariates
@@ -55,10 +54,13 @@
 #' BIC=fitcsi$BIC
 #'}
 
-
-cubecsi<-function(m,ordinal,W,starting,maxiter,toler,summary){
+cubecsi<-function(m,ordinal,W,starting,maxiter,toler){
   tt0<-proc.time()
   n<-length(ordinal)
+  W<-as.matrix(W)
+  if (ncol(W)==1){
+    W<-as.numeric(W)
+  }
   q<-length(starting)-3
   pai<-starting[1]; gama<-starting[2:(q+2)]; phi<-starting[q+3];
   #(0)# log-lik
@@ -97,62 +99,25 @@ cubecsi<-function(m,ordinal,W,starting,maxiter,toler,summary){
     errstd<-sqrt(diag(varmat))
     ddd<-diag(sqrt(1/diag(varmat)))
     wald<-vettestim/errstd
-    pval<-c(round(2*(1-pnorm(abs(wald))),20))
+    pval<-2*(1-pnorm(abs(wald)))
     cormat<-(ddd%*%varmat)%*%ddd
     trvarmat<-sum(diag(varmat))
     ICOMP<- -2*loglik + nparam*log(trvarmat/nparam) - log(det(varmat))
     
-    errstd<-round(errstd,5)  
-    wald<-round(wald,5)
-    pval<-round(pval,5)
+    errstd<-errstd  
+    wald<-wald
+    pval<-pval
   }
   
-  nomi<-c("pai    ",paste("gamma",0:(length(gama)-1),sep="_"),"phi    ")
-  stime<-round(vettestim,5)
+  # nomi<-c("pai    ",paste("gamma",0:(length(gama)-1),sep="_"),"phi    ")
+  stime<-vettestim
   ####################################################################
   ### Print CUBEcsi results of ML estimation  
   ####################################################################
-  rownames(cormat)<-nomi; colnames(cormat)<-nomi; 
+  # rownames(cormat)<-nomi; colnames(cormat)<-nomi; 
   durata<-proc.time()-tt0;durata<-durata[1];
-  if (summary==TRUE){
-    cat("\n")
-    cat("=======================================================================","\n")
-    cat("==> CUBEcsi Program <<<=== ML-estimates via optim post E-M algorithm   ","\n")
-    cat("=======================================================================","\n")
-    cat("                Covariates for feeling ==> q =", q,"\n")
-    cat("=======================================================================","\n")
-    cat("  *** m=", m,"       *** Sample size: n=", n,"                         ", "\n")
-    cat("=======================================================================","\n")
-    cat("parameters  ML-estimates  stand.errors    Wald-test      p-value ","\n")
-    cat("=======================================================================","\n")
-    for(i in 1:length(nomi)){
-      cat(nomi[i],"     ",stime[i],"      ",errstd[i],"       ",wald[i],"      ",pval[i],"\n")
-    }
-    cat("=======================================================================","\n")
-    cat("                         Parameters correlation matrix","\n") 
-    print(round(cormat,3))
-    cat("=======================================================================","\n")
-    cat("Log-lik(pai^,gama^,phi^) =",round(loglik,digits=8),"\n")
-    cat("Mean Log-likelihood      =",round(loglik/n,digits=8),"\n")
-    cat("-----------------------------------------------------------------------","\n")
-    cat("AIC-CUBEcsi       =",round(AICCUBEcsi,digits=8),"\n")
-    cat("BIC-CUBEcsi        =",round(BICCUBEcsi,digits=8),"\n")
-    cat("ICOMP-CUBEcsi      =",round(ICOMP,digits=8),"\n")
-    cat("=======================================================================","\n")  
-    cat("Elapsed time     =",durata,"seconds","=====>>>",date(),"\n")
-    cat("=======================================================================","\n")  
-    
-  }
-  ################################################################
-  #        Assignments as global variables
-  ################################################################
-  #   assign('pai',pai,pos=1)
-  #   assign('gama',gama,pos=1)
-  #   assign('phi',phi,pos=1)
-  #   assign('varmat',varmat,pos=1)
-  #   assign('loglik',loglik,pos=1)
   
-  # cat("=======================================================================","\n")
-  #cat("Convergence code =",optimparam$convergence,"\n")
-  results<-list('estimates'=stime, 'loglik'=loglik, 'varmat'=varmat,'BIC'= round(BICCUBEcsi,digits=8))
+  
+  results<-list('estimates'=stime, 'loglik'=loglik, 'varmat'=varmat,
+                'BIC'= BICCUBEcsi,'time'=durata,'niter'=1)
 }
