@@ -4,27 +4,36 @@
 #' @aliases inibestcube
 #' @usage inibestcube(m,ordinal)
 #' @param m Number of ordinal categories
-#' @param ordinal Vector of ordinal responses
+#' @param ordinal Vector of ordinal responses (factor type)
 #' @export inibestcube
 #' @return A vector \eqn{(\pi, \xi ,\phi)} of parameter estimates of a CUBE model without covariates
 #' @keywords htest utilities
 #' @seealso \code{\link{inibestcubecov}}, \code{\link{inibestcubecsi}}
 #' @examples
 #' data(relgoods)
-#' m<-10
-#' ordinal<-na.omit(relgoods[,44])
-#' estim<-inibestcube(m,ordinal)     # Preliminary estimates (pai,csi,phi)
+#' attach(relgoods)
+#' m<-length(levels(SocialNetwork))
+#' estim<-inibestcube(m,SocialNetwork)     # Preliminary estimates (pai,csi,phi)
 
 
-inibestcube <-
-function(m,ordinal){
-  freq<-tabulate(ordinal,nbins=m)  
+inibestcube <- function(m,ordinal){
+  
+  if (!is.factor(ordinal)){
+    stop("Response must be an ordered factor")
+  }
+  
+  ord<-unclass(ordinal)
+  
+  
+  freq<-tabulate(ord,nbins=m)  
   inipaicsi<-inibest(m,freq)
   pai<-inipaicsi[1];csi<-inipaicsi[2];
-  aver<-mean(ordinal) 
-  varcamp<-mean(ordinal^2)-aver^2
+  aver<-mean(ord) 
+  varcamp<-mean(ord^2)-aver^2
   varcub<-varcub00(m,pai,csi) 
   phist<-min(max((varcub-varcamp)/(-pai*csi*(1-csi)*(m-1)*(m-2)-varcub+varcamp),0.01),0.5)
-  initial<-c(pai,csi,phist)
+  initial<-as.matrix(c(pai,csi,phist))
+  rownames(initial)<-list("pai","csi","phi"); colnames(initial)<-""
+  
   return(initial)
 }
