@@ -14,6 +14,12 @@
 
 loglikcubp0 <-
 function(m,ordinal,Y,bbet,ccsi){
+  
+  if (is.factor(ordinal)){
+    ordinal<-unclass(ordinal)
+    
+  }
+  Y<-as.matrix(Y)
   prob<-probbit(m,ccsi)
   probn<-prob[ordinal]
   eta<-logis(Y,bbet)
