@@ -9,13 +9,12 @@
 #' @param omega Vector of parameters for explaining the shelter effect, 
 #' with length equal to NCOL(X)+1 to account for an intercept term (first entry of omega)
 #' @param shelter Category corresponding to the shelter choice
-#' @seealso \code{\link{CUSH}}
 #' @keywords internal
 #' 
 
 
-loglikcushcov <-
-function(m,ordinal,X,omega,shelter){
+loglikcushcov <-function(m,ordinal,X,omega,shelter){
+  X<-as.matrix(X)
   deltavett<-logis(X,omega)
   dummy<-ifelse(ordinal==shelter,1,0)
   probi<-deltavett*(dummy-1/m)+1/m
