@@ -4,15 +4,15 @@
 #' to explain the preference parameter.
 #' @usage loglikIHG(ordinal,m,param,U=0)
 #' @export loglikIHG
-#' @param ordinal Vector of ordinal responses
+#' @param ordinal Vector of ordinal responses (factor type)
 #' @param m Number of ordinal categories
 #' @param param Vector of parameters for the specified IHG model
 #' @param U Matrix of selected covariates to explain the preference parameter (default: no covariate is included 
 #' in the model)
-#' @details If no covariate is included in the model, then "param" is the estimate of the preference
-#' parameter (theta), otherwise "param" has length equal to NCOL(U) + 1 to account for an intercept  
+#' @details If no covariate is included in the model, then \code{param} is the estimate of the preference
+#' parameter (theta), otherwise \code{param} has length equal to NCOL(U) + 1 to account for an intercept  
 #' term (first entry)
-#' @seealso  \code{\link{IHG}}
+#' @seealso  \code{\link{GEM}}, \code{\link{logLik}}
 #' @keywords htest
 #' @examples
 #' #### Log-likelihood of an IHG model with no covariate
@@ -22,20 +22,27 @@
 #' ##################################
 #' #### Log-likelihood of a IHG model with covariate 
 #' data(relgoods)
+#' attach(relgoods)
 #' m<-10
-#' ordinal<-relgoods[,41]
-#' gender<-relgoods[,9]
-#' nona<-na.omit(cbind(ordinal,gender))
-#' ordinal<-nona[,1]
-#' gender<-nona[,2]
-#' nu<-c(-1.55,-0.11) # first entry: intercept term
-#' loglik<-loglikIHG(ordinal, m, param=nu, U=gender)
+#' naord<-which(is.na(HandWork))
+#' nacov<-which(is.na(Gender))
+#' na<-union(naord,nacov)
+#' ordinal<-HandWork[-na]; U<-Gender[-na]
+#' nu<-c(-1.55,-0.11)     # first entry: intercept term
+#' loglik<-loglikIHG(ordinal,m,param=nu,U=U)
 
 
 
 
 loglikIHG <-
 function(ordinal,m,param,U=0){
+  if (!is.factor(ordinal)){
+    stop("Response must be an ordered factor")
+  }
+  
+  ordinal<-unclass(ordinal)
+
+  
   nu<-NROW(U)
   if (nu==1){
     theta<-param
@@ -44,6 +51,11 @@ function(ordinal,m,param,U=0){
 
   } else {
    nu<-param
+   U<-as.matrix(U)
+   if (ncol(U)==1){
+     U<-as.numeric(U)
+   }
+ 
    loglik<-loglikihgcov(m,ordinal,U,nu)  
   }
 
