@@ -3,18 +3,18 @@
 #' @description Compute the probability distribution of a CUB model with covariates
 #'  for the feeling component.
 #' @export probcub0q
-#' @usage probcub0q(m, ordinal, W, pai, gama)
+#' @usage probcub0q(m,ordinal,W,pai,gama)
 #' @keywords distribution
 #' @param m Number of ordinal categories
-#' @param ordinal Vector of ordinal responses
+#' @param ordinal Vector of ordinal responses (of factor type)
 #' @param W Matrix of covariates for explaining the feeling component
 #' NCOL(Y)+1 to include an intercept term in the model (first entry)
 #' @param pai Uncertainty parameter
 #' @param gama Vector of parameters for the feeling component, whose length equals 
 #' NCOL(W)+1 to include an intercept term in the model (first entry)
 #' @return A vector of the same length as ordinal, whose i-th component is the
-#' probability of the i-th observation according to a CUB model with the corresponding values 
-#' of the covariates for the feeling component and coefficients specified in gama
+#' probability of the i-th observation according to a CUB distribution with the corresponding values 
+#' of the covariates for the feeling component and coefficients specified in \code{gama}
 #' @seealso \code{\link{bitgama}}, \code{\link{probcub00}}, \code{\link{probcubp0}}, 
 #' \code{\link{probcubpq}}
 #' @references 
@@ -27,17 +27,27 @@
 #' J. Wiley and Sons, Chichester, 231--258
 #' @examples
 #' data(relgoods)
+#' attach(relgoods)
 #' m<-10
-#' ordinal<-relgoods[,29]
-#' gender<-relgoods[,2]
-#' data<-na.omit(cbind(ordinal,gender))
-#' ordinalnew<-data[,1]
-#' W<-data[,2]
-#' pai<-0.44
-#' gama<-c(-0.91,-0.7)
-#' pr<-probcub0q(m,ordinalnew,W,pai,gama)
+#' naord<-which(is.na(Physician))
+#' nacov<-which(is.na(Gender))
+#' na<-union(naord,nacov)
+#' ordinal<-Physician[-na]
+#' W<-Gender[-na]
+#' pai<-0.44; gama<-c(-0.91,-0.7)
+#' pr<-probcub0q(m,ordinal,W,pai,gama)
 
 probcub0q <-
 function(m,ordinal,W,pai,gama){
-  pai*(bitgama(m,ordinal,W,gama)-1/m)+1/m
+  
+  if (!is.factor(ordinal)){
+    stop("Response must be an ordered factor")
+  }
+  W<-as.matrix(W)
+  
+  if (ncol(W)==1){
+    W<-as.numeric(W)
+  }
+  
+  as.numeric(pai*(bitgama(m,ordinal,W,gama)-1/m)+1/m)
 }
