@@ -1,9 +1,9 @@
 #' @title Simulation routine for CUB models with shelter effect
 #' @aliases simcubshe
-#' @description Generate \eqn{n} pseudo-random numbers according to the CUB distribution
-#'  with shelter effect and with given parameters.
+#' @description Generate \eqn{n} pseudo-random observations following the given CUB distribution
+#'  with shelter effect.
 #' @keywords distribution
-#' @usage simcubshe(n, m, pai, csi, delta, shelter)
+#' @usage simcubshe(n,m,pai,csi,delta,shelter)
 #' @export simcubshe
 #' @import stats
 #' @param n Number of simulated observations
@@ -20,8 +20,8 @@
 #' csi<-0.3
 #' delta<-0.2
 #' shelter<-3
-#' simulation<-simcubshe(n, m, pai, csi, delta, shelter)
-#' plot(table(simulation), xlab="Ordinal categories",ylab="Frequencies")
+#' simulation<-simcubshe(n,m,pai,csi,delta,shelter)
+#' plot(table(simulation),xlab="Ordinal categories",ylab="Frequencies")
 
 
 simcubshe <-
@@ -29,5 +29,6 @@ function(n,m,pai,csi,delta,shelter){
   dicopai<-runif(n)<pai
   dicodelta<-runif(n)<delta
   cub00<-dicopai*(1+rbinom(n,m-1,1-csi))+(1-dicopai)*sample(m,n,replace=TRUE)
-  return((1-dicodelta)*cub00+dicodelta*shelter)
+  ord<-(1-dicodelta)*cub00+dicodelta*shelter
+  return(factor(ord,ordered=TRUE))
 }
