@@ -1,9 +1,8 @@
 #' @title Simulation routine for IHG models
 #' @aliases simihg
-#' @description Generate n pseudo-random numbers according to the IHG distribution with given
-#'  preference parameter \eqn{\theta}.
+#' @description Generate n pseudo-random observations following the given IHG distribution.
 #' @keywords distribution
-#' @usage simihg(n, m, theta)
+#' @usage simihg(n,m,theta)
 #' @export simihg
 #' @param n Number of simulated observations
 #' @param m Number of ordinal categories
@@ -13,8 +12,8 @@
 #' n<-300
 #' m<-9
 #' theta<-0.4
-#' simulation<-simihg(n, m, theta)
-#' plot(table(simulation), xlab="Number of categories", ylab="Frequencies")
+#' simulation<-simihg(n,m,theta)
+#' plot(table(simulation),xlab="Number of categories",ylab="Frequencies")
 
 
 
@@ -23,5 +22,5 @@ function(n,m,theta){
   B<-(m-1)*theta/(1-theta)
   psi<-1-runif(n)^(1/B)
   vett<-1+rbinom(n,m-1,psi)
-  return(vett)
+  return(factor(vett,ordered=TRUE))
 }
